



# High Photon OS Security Update

## Summary

Advisory Id     : PHSA-2023-4.0-0501

Type            : Security

Severity        : ['Important']

Issue date      : 2023-10-15

Affected Release: 4.0

## Details

Updates of ['nghttp2'] packages of Photon OS have been released.
## Affected Packages

### Important

nghttp2 - ['[CVE-2023-44487](https://nvd.nist.gov/vuln/detail/CVE-2023-44487)']

## Solution

Update the affected packages (tdnf update package)
